@@ -114,7 +114,7 @@ dialog_response (GtkWidget *widget,
 {
 	if (response_id == GTK_RESPONSE_HELP)
 		capplet_help (GTK_WINDOW (widget),
-			"wgoscustdesk.xml",
+			"user-guide.xml",
 			"goscustperiph-2");
 	else if (response_id == 0)
 		accessibility_button_clicked (NULL, NULL);
@@ -166,7 +166,9 @@ setup_dialog (GladeXML       *dialog,
 	gconf_peditor_new_boolean
 		(changeset, "/desktop/gnome/typing_break/allow_postpone", WID ("break_postponement_toggle"), NULL);
 	g_signal_connect (G_OBJECT (WID ("keyboard_dialog")), "response", (GCallback) dialog_response, changeset);
-        
+	
+	gtk_label_set_use_markup (GTK_LABEL (GTK_BIN (WID ("break_enabled_toggle"))->child), TRUE);
+	
         setup_xkb_tabs(dialog,changeset);
 }
 
@@ -247,10 +249,10 @@ main (int argc, char **argv)
 		dialog = create_dialog ();
 		setup_dialog (dialog, changeset);
 		if (switch_to_typing_break_page) {
-			gtk_notebook_set_current_page (GTK_NOTEBOOK (WID ("keyboard_notebook")), 1);
+			gtk_notebook_set_current_page (GTK_NOTEBOOK (WID ("keyboard_notebook")), 3);
 		}
 		capplet_set_icon (WID ("keyboard_dialog"),
-				  "keyboard-capplet.png");
+				  "gnome-dev-keyboard");
 		gtk_widget_show (WID ("keyboard_dialog"));
 		gtk_main ();
 	}
