@@ -44,6 +44,7 @@
 #include "gnome-settings-font.h"
 #include "gnome-settings-xsettings.h"
 #include "gnome-settings-mouse.h"
+#include "gnome-settings-keyboard-xkb.h"
 #include "gnome-settings-keyboard.h"
 #include "gnome-settings-background.h"
 #include "gnome-settings-sound.h"
@@ -51,8 +52,10 @@
 #include "gnome-settings-screensaver.h"
 #include "gnome-settings-default-editor.h"
 #include "gnome-settings-keybindings.h"
+#include "gnome-settings-multimedia-keys.h"
 #include "gnome-settings-gtk1theme.h"
 #include "gnome-settings-xrdb.h"
+#include "gnome-settings-typing-break.h"
 
 #include "GNOME_SettingsDaemon.h"
 
@@ -271,7 +274,11 @@ gnome_settings_daemon_new (void)
   gnome_settings_font_init (client);
   gnome_settings_xsettings_init (client);
   gnome_settings_mouse_init (client);
+/* Essential - xkb initialization should happen before */
+  gnome_settings_keyboard_xkb_init (client);
   gnome_settings_keyboard_init (client);
+  gnome_settings_multimedia_keys_init (client);
+/* */
   gnome_settings_sound_init (client);
   gnome_settings_accessibility_keyboard_init (client);
   gnome_settings_screensaver_init (client);
@@ -280,6 +287,7 @@ gnome_settings_daemon_new (void)
   gnome_settings_keybindings_init (client);
   gnome_settings_gtk1_theme_init (client);
   gnome_settings_xrdb_init (client);
+  gnome_settings_typing_break_init (client);
 
   for (list = directories; list; list = list->next)
     {
@@ -320,7 +328,11 @@ gnome_settings_daemon_new (void)
   gnome_settings_font_load (client);
   gnome_settings_xsettings_load (client);
   gnome_settings_mouse_load (client);
+/* Essential - xkb initialization should happen before */
+  gnome_settings_keyboard_xkb_load (client);
   gnome_settings_keyboard_load (client);
+  gnome_settings_multimedia_keys_load (client);
+/* */
   gnome_settings_sound_load (client);
   gnome_settings_accessibility_keyboard_load (client);
   gnome_settings_screensaver_load (client);
@@ -329,6 +341,7 @@ gnome_settings_daemon_new (void)
   gnome_settings_keybindings_load (client);
   gnome_settings_gtk1_theme_load (client);
   gnome_settings_xrdb_load (client);
+  gnome_settings_typing_break_load (client);
 
   return G_OBJECT (daemon);
 }
